# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.enums.customer_match_upload_key_type_pb2 import (
    CustomerMatchUploadKeyTypeEnum as google___ads___googleads___v6___enums___customer_match_upload_key_type_pb2___CustomerMatchUploadKeyTypeEnum,
)
from google.ads.google_ads.v6.proto.enums.user_list_combined_rule_operator_pb2 import (
    UserListCombinedRuleOperatorEnum as google___ads___googleads___v6___enums___user_list_combined_rule_operator_pb2___UserListCombinedRuleOperatorEnum,
)
from google.ads.google_ads.v6.proto.enums.user_list_crm_data_source_type_pb2 import (
    UserListCrmDataSourceTypeEnum as google___ads___googleads___v6___enums___user_list_crm_data_source_type_pb2___UserListCrmDataSourceTypeEnum,
)
from google.ads.google_ads.v6.proto.enums.user_list_date_rule_item_operator_pb2 import (
    UserListDateRuleItemOperatorEnum as google___ads___googleads___v6___enums___user_list_date_rule_item_operator_pb2___UserListDateRuleItemOperatorEnum,
)
from google.ads.google_ads.v6.proto.enums.user_list_logical_rule_operator_pb2 import (
    UserListLogicalRuleOperatorEnum as google___ads___googleads___v6___enums___user_list_logical_rule_operator_pb2___UserListLogicalRuleOperatorEnum,
)
from google.ads.google_ads.v6.proto.enums.user_list_number_rule_item_operator_pb2 import (
    UserListNumberRuleItemOperatorEnum as google___ads___googleads___v6___enums___user_list_number_rule_item_operator_pb2___UserListNumberRuleItemOperatorEnum,
)
from google.ads.google_ads.v6.proto.enums.user_list_prepopulation_status_pb2 import (
    UserListPrepopulationStatusEnum as google___ads___googleads___v6___enums___user_list_prepopulation_status_pb2___UserListPrepopulationStatusEnum,
)
from google.ads.google_ads.v6.proto.enums.user_list_rule_type_pb2 import (
    UserListRuleTypeEnum as google___ads___googleads___v6___enums___user_list_rule_type_pb2___UserListRuleTypeEnum,
)
from google.ads.google_ads.v6.proto.enums.user_list_string_rule_item_operator_pb2 import (
    UserListStringRuleItemOperatorEnum as google___ads___googleads___v6___enums___user_list_string_rule_item_operator_pb2___UserListStringRuleItemOperatorEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class SimilarUserListInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    seed_user_list: typing___Text = ...
    def __init__(
        self, *, seed_user_list: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_seed_user_list", b"_seed_user_list", "seed_user_list", b"seed_user_list"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_seed_user_list", b"_seed_user_list", "seed_user_list", b"seed_user_list"
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_seed_user_list", b"_seed_user_list"],
    ) -> typing_extensions___Literal["seed_user_list"]: ...

type___SimilarUserListInfo = SimilarUserListInfo

class CrmBasedUserListInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    app_id: typing___Text = ...
    upload_key_type: google___ads___googleads___v6___enums___customer_match_upload_key_type_pb2___CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyTypeValue = ...
    data_source_type: google___ads___googleads___v6___enums___user_list_crm_data_source_type_pb2___UserListCrmDataSourceTypeEnum.UserListCrmDataSourceTypeValue = ...
    def __init__(
        self,
        *,
        app_id: typing___Optional[typing___Text] = None,
        upload_key_type: typing___Optional[
            google___ads___googleads___v6___enums___customer_match_upload_key_type_pb2___CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyTypeValue
        ] = None,
        data_source_type: typing___Optional[
            google___ads___googleads___v6___enums___user_list_crm_data_source_type_pb2___UserListCrmDataSourceTypeEnum.UserListCrmDataSourceTypeValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_app_id", b"_app_id", "app_id", b"app_id"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_app_id",
            b"_app_id",
            "app_id",
            b"app_id",
            "data_source_type",
            b"data_source_type",
            "upload_key_type",
            b"upload_key_type",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_app_id", b"_app_id"]
    ) -> typing_extensions___Literal["app_id"]: ...

type___CrmBasedUserListInfo = CrmBasedUserListInfo

class UserListRuleInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    rule_type: google___ads___googleads___v6___enums___user_list_rule_type_pb2___UserListRuleTypeEnum.UserListRuleTypeValue = ...
    @property
    def rule_item_groups(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___UserListRuleItemGroupInfo
    ]: ...
    def __init__(
        self,
        *,
        rule_type: typing___Optional[
            google___ads___googleads___v6___enums___user_list_rule_type_pb2___UserListRuleTypeEnum.UserListRuleTypeValue
        ] = None,
        rule_item_groups: typing___Optional[
            typing___Iterable[type___UserListRuleItemGroupInfo]
        ] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "rule_item_groups", b"rule_item_groups", "rule_type", b"rule_type"
        ],
    ) -> None: ...

type___UserListRuleInfo = UserListRuleInfo

class UserListRuleItemGroupInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def rule_items(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___UserListRuleItemInfo
    ]: ...
    def __init__(
        self,
        *,
        rule_items: typing___Optional[
            typing___Iterable[type___UserListRuleItemInfo]
        ] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["rule_items", b"rule_items"]
    ) -> None: ...

type___UserListRuleItemGroupInfo = UserListRuleItemGroupInfo

class UserListRuleItemInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    name: typing___Text = ...
    @property
    def number_rule_item(self) -> type___UserListNumberRuleItemInfo: ...
    @property
    def string_rule_item(self) -> type___UserListStringRuleItemInfo: ...
    @property
    def date_rule_item(self) -> type___UserListDateRuleItemInfo: ...
    def __init__(
        self,
        *,
        name: typing___Optional[typing___Text] = None,
        number_rule_item: typing___Optional[type___UserListNumberRuleItemInfo] = None,
        string_rule_item: typing___Optional[type___UserListStringRuleItemInfo] = None,
        date_rule_item: typing___Optional[type___UserListDateRuleItemInfo] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_name",
            b"_name",
            "date_rule_item",
            b"date_rule_item",
            "name",
            b"name",
            "number_rule_item",
            b"number_rule_item",
            "rule_item",
            b"rule_item",
            "string_rule_item",
            b"string_rule_item",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_name",
            b"_name",
            "date_rule_item",
            b"date_rule_item",
            "name",
            b"name",
            "number_rule_item",
            b"number_rule_item",
            "rule_item",
            b"rule_item",
            "string_rule_item",
            b"string_rule_item",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_name", b"_name"]
    ) -> typing_extensions___Literal["name"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["rule_item", b"rule_item"]
    ) -> typing_extensions___Literal[
        "number_rule_item", "string_rule_item", "date_rule_item"
    ]: ...

type___UserListRuleItemInfo = UserListRuleItemInfo

class UserListDateRuleItemInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    operator: google___ads___googleads___v6___enums___user_list_date_rule_item_operator_pb2___UserListDateRuleItemOperatorEnum.UserListDateRuleItemOperatorValue = ...
    value: typing___Text = ...
    offset_in_days: builtin___int = ...
    def __init__(
        self,
        *,
        operator: typing___Optional[
            google___ads___googleads___v6___enums___user_list_date_rule_item_operator_pb2___UserListDateRuleItemOperatorEnum.UserListDateRuleItemOperatorValue
        ] = None,
        value: typing___Optional[typing___Text] = None,
        offset_in_days: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_offset_in_days",
            b"_offset_in_days",
            "_value",
            b"_value",
            "offset_in_days",
            b"offset_in_days",
            "value",
            b"value",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_offset_in_days",
            b"_offset_in_days",
            "_value",
            b"_value",
            "offset_in_days",
            b"offset_in_days",
            "operator",
            b"operator",
            "value",
            b"value",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_offset_in_days", b"_offset_in_days"],
    ) -> typing_extensions___Literal["offset_in_days"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_value", b"_value"]
    ) -> typing_extensions___Literal["value"]: ...

type___UserListDateRuleItemInfo = UserListDateRuleItemInfo

class UserListNumberRuleItemInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    operator: google___ads___googleads___v6___enums___user_list_number_rule_item_operator_pb2___UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperatorValue = ...
    value: builtin___float = ...
    def __init__(
        self,
        *,
        operator: typing___Optional[
            google___ads___googleads___v6___enums___user_list_number_rule_item_operator_pb2___UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperatorValue
        ] = None,
        value: typing___Optional[builtin___float] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal["_value", b"_value", "value", b"value"],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_value", b"_value", "operator", b"operator", "value", b"value"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_value", b"_value"]
    ) -> typing_extensions___Literal["value"]: ...

type___UserListNumberRuleItemInfo = UserListNumberRuleItemInfo

class UserListStringRuleItemInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    operator: google___ads___googleads___v6___enums___user_list_string_rule_item_operator_pb2___UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperatorValue = ...
    value: typing___Text = ...
    def __init__(
        self,
        *,
        operator: typing___Optional[
            google___ads___googleads___v6___enums___user_list_string_rule_item_operator_pb2___UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperatorValue
        ] = None,
        value: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal["_value", b"_value", "value", b"value"],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_value", b"_value", "operator", b"operator", "value", b"value"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_value", b"_value"]
    ) -> typing_extensions___Literal["value"]: ...

type___UserListStringRuleItemInfo = UserListStringRuleItemInfo

class CombinedRuleUserListInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    rule_operator: google___ads___googleads___v6___enums___user_list_combined_rule_operator_pb2___UserListCombinedRuleOperatorEnum.UserListCombinedRuleOperatorValue = ...
    @property
    def left_operand(self) -> type___UserListRuleInfo: ...
    @property
    def right_operand(self) -> type___UserListRuleInfo: ...
    def __init__(
        self,
        *,
        left_operand: typing___Optional[type___UserListRuleInfo] = None,
        right_operand: typing___Optional[type___UserListRuleInfo] = None,
        rule_operator: typing___Optional[
            google___ads___googleads___v6___enums___user_list_combined_rule_operator_pb2___UserListCombinedRuleOperatorEnum.UserListCombinedRuleOperatorValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "left_operand", b"left_operand", "right_operand", b"right_operand"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "left_operand",
            b"left_operand",
            "right_operand",
            b"right_operand",
            "rule_operator",
            b"rule_operator",
        ],
    ) -> None: ...

type___CombinedRuleUserListInfo = CombinedRuleUserListInfo

class DateSpecificRuleUserListInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    start_date: typing___Text = ...
    end_date: typing___Text = ...
    @property
    def rule(self) -> type___UserListRuleInfo: ...
    def __init__(
        self,
        *,
        rule: typing___Optional[type___UserListRuleInfo] = None,
        start_date: typing___Optional[typing___Text] = None,
        end_date: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_end_date",
            b"_end_date",
            "_start_date",
            b"_start_date",
            "end_date",
            b"end_date",
            "rule",
            b"rule",
            "start_date",
            b"start_date",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_end_date",
            b"_end_date",
            "_start_date",
            b"_start_date",
            "end_date",
            b"end_date",
            "rule",
            b"rule",
            "start_date",
            b"start_date",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_end_date", b"_end_date"]
    ) -> typing_extensions___Literal["end_date"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_start_date", b"_start_date"]
    ) -> typing_extensions___Literal["start_date"]: ...

type___DateSpecificRuleUserListInfo = DateSpecificRuleUserListInfo

class ExpressionRuleUserListInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def rule(self) -> type___UserListRuleInfo: ...
    def __init__(
        self, *, rule: typing___Optional[type___UserListRuleInfo] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["rule", b"rule"]
    ) -> builtin___bool: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["rule", b"rule"]
    ) -> None: ...

type___ExpressionRuleUserListInfo = ExpressionRuleUserListInfo

class RuleBasedUserListInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    prepopulation_status: google___ads___googleads___v6___enums___user_list_prepopulation_status_pb2___UserListPrepopulationStatusEnum.UserListPrepopulationStatusValue = ...
    @property
    def combined_rule_user_list(self) -> type___CombinedRuleUserListInfo: ...
    @property
    def date_specific_rule_user_list(self) -> type___DateSpecificRuleUserListInfo: ...
    @property
    def expression_rule_user_list(self) -> type___ExpressionRuleUserListInfo: ...
    def __init__(
        self,
        *,
        prepopulation_status: typing___Optional[
            google___ads___googleads___v6___enums___user_list_prepopulation_status_pb2___UserListPrepopulationStatusEnum.UserListPrepopulationStatusValue
        ] = None,
        combined_rule_user_list: typing___Optional[
            type___CombinedRuleUserListInfo
        ] = None,
        date_specific_rule_user_list: typing___Optional[
            type___DateSpecificRuleUserListInfo
        ] = None,
        expression_rule_user_list: typing___Optional[
            type___ExpressionRuleUserListInfo
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "combined_rule_user_list",
            b"combined_rule_user_list",
            "date_specific_rule_user_list",
            b"date_specific_rule_user_list",
            "expression_rule_user_list",
            b"expression_rule_user_list",
            "rule_based_user_list",
            b"rule_based_user_list",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "combined_rule_user_list",
            b"combined_rule_user_list",
            "date_specific_rule_user_list",
            b"date_specific_rule_user_list",
            "expression_rule_user_list",
            b"expression_rule_user_list",
            "prepopulation_status",
            b"prepopulation_status",
            "rule_based_user_list",
            b"rule_based_user_list",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "rule_based_user_list", b"rule_based_user_list"
        ],
    ) -> typing_extensions___Literal[
        "combined_rule_user_list",
        "date_specific_rule_user_list",
        "expression_rule_user_list",
    ]: ...

type___RuleBasedUserListInfo = RuleBasedUserListInfo

class LogicalUserListInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def rules(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___UserListLogicalRuleInfo
    ]: ...
    def __init__(
        self,
        *,
        rules: typing___Optional[
            typing___Iterable[type___UserListLogicalRuleInfo]
        ] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["rules", b"rules"]
    ) -> None: ...

type___LogicalUserListInfo = LogicalUserListInfo

class UserListLogicalRuleInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    operator: google___ads___googleads___v6___enums___user_list_logical_rule_operator_pb2___UserListLogicalRuleOperatorEnum.UserListLogicalRuleOperatorValue = ...
    @property
    def rule_operands(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___LogicalUserListOperandInfo
    ]: ...
    def __init__(
        self,
        *,
        operator: typing___Optional[
            google___ads___googleads___v6___enums___user_list_logical_rule_operator_pb2___UserListLogicalRuleOperatorEnum.UserListLogicalRuleOperatorValue
        ] = None,
        rule_operands: typing___Optional[
            typing___Iterable[type___LogicalUserListOperandInfo]
        ] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "operator", b"operator", "rule_operands", b"rule_operands"
        ],
    ) -> None: ...

type___UserListLogicalRuleInfo = UserListLogicalRuleInfo

class LogicalUserListOperandInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    user_list: typing___Text = ...
    def __init__(
        self, *, user_list: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_user_list", b"_user_list", "user_list", b"user_list"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_user_list", b"_user_list", "user_list", b"user_list"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_user_list", b"_user_list"]
    ) -> typing_extensions___Literal["user_list"]: ...

type___LogicalUserListOperandInfo = LogicalUserListOperandInfo

class BasicUserListInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def actions(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___UserListActionInfo
    ]: ...
    def __init__(
        self,
        *,
        actions: typing___Optional[typing___Iterable[type___UserListActionInfo]] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["actions", b"actions"]
    ) -> None: ...

type___BasicUserListInfo = BasicUserListInfo

class UserListActionInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    conversion_action: typing___Text = ...
    remarketing_action: typing___Text = ...
    def __init__(
        self,
        *,
        conversion_action: typing___Optional[typing___Text] = None,
        remarketing_action: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "conversion_action",
            b"conversion_action",
            "remarketing_action",
            b"remarketing_action",
            "user_list_action",
            b"user_list_action",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "conversion_action",
            b"conversion_action",
            "remarketing_action",
            b"remarketing_action",
            "user_list_action",
            b"user_list_action",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "user_list_action", b"user_list_action"
        ],
    ) -> typing_extensions___Literal["conversion_action", "remarketing_action"]: ...

type___UserListActionInfo = UserListActionInfo



# Stubs for google.ads.google_ads.interceptors (Python 3)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from .exception_interceptor import ExceptionInterceptor
from .logging_interceptor import LoggingInterceptor
from .metadata_interceptor import MetadataInterceptor



from typing import Any

class CampaignAudienceViewServiceStub:
    GetCampaignAudienceView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class CampaignAudienceViewServiceServicer:
    def GetCampaignAudienceView(self, request: Any, context: Any) -> None: ...

def add_CampaignAudienceViewServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class MessagePlaceholderFieldEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    MessagePlaceholderFieldValue = typing___NewType(
        "MessagePlaceholderFieldValue", builtin___int
    )
    type___MessagePlaceholderFieldValue = MessagePlaceholderFieldValue
    MessagePlaceholderField: _MessagePlaceholderField
    class _MessagePlaceholderField(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            MessagePlaceholderFieldEnum.MessagePlaceholderFieldValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            MessagePlaceholderFieldEnum.MessagePlaceholderFieldValue, 0
        )
        UNKNOWN = typing___cast(
            MessagePlaceholderFieldEnum.MessagePlaceholderFieldValue, 1
        )
        BUSINESS_NAME = typing___cast(
            MessagePlaceholderFieldEnum.MessagePlaceholderFieldValue, 2
        )
        COUNTRY_CODE = typing___cast(
            MessagePlaceholderFieldEnum.MessagePlaceholderFieldValue, 3
        )
        PHONE_NUMBER = typing___cast(
            MessagePlaceholderFieldEnum.MessagePlaceholderFieldValue, 4
        )
        MESSAGE_EXTENSION_TEXT = typing___cast(
            MessagePlaceholderFieldEnum.MessagePlaceholderFieldValue, 5
        )
        MESSAGE_TEXT = typing___cast(
            MessagePlaceholderFieldEnum.MessagePlaceholderFieldValue, 6
        )
    UNSPECIFIED = typing___cast(
        MessagePlaceholderFieldEnum.MessagePlaceholderFieldValue, 0
    )
    UNKNOWN = typing___cast(MessagePlaceholderFieldEnum.MessagePlaceholderFieldValue, 1)
    BUSINESS_NAME = typing___cast(
        MessagePlaceholderFieldEnum.MessagePlaceholderFieldValue, 2
    )
    COUNTRY_CODE = typing___cast(
        MessagePlaceholderFieldEnum.MessagePlaceholderFieldValue, 3
    )
    PHONE_NUMBER = typing___cast(
        MessagePlaceholderFieldEnum.MessagePlaceholderFieldValue, 4
    )
    MESSAGE_EXTENSION_TEXT = typing___cast(
        MessagePlaceholderFieldEnum.MessagePlaceholderFieldValue, 5
    )
    MESSAGE_TEXT = typing___cast(
        MessagePlaceholderFieldEnum.MessagePlaceholderFieldValue, 6
    )
    type___MessagePlaceholderField = MessagePlaceholderField
    def __init__(self,) -> None: ...

type___MessagePlaceholderFieldEnum = MessagePlaceholderFieldEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AdvertisingChannelTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AdvertisingChannelTypeValue = typing___NewType(
        "AdvertisingChannelTypeValue", builtin___int
    )
    type___AdvertisingChannelTypeValue = AdvertisingChannelTypeValue
    AdvertisingChannelType: _AdvertisingChannelType
    class _AdvertisingChannelType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue, 0
        )
        UNKNOWN = typing___cast(
            AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue, 1
        )
        SEARCH = typing___cast(
            AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue, 2
        )
        DISPLAY = typing___cast(
            AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue, 3
        )
        SHOPPING = typing___cast(
            AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue, 4
        )
        HOTEL = typing___cast(AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue, 5)
        VIDEO = typing___cast(AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue, 6)
        MULTI_CHANNEL = typing___cast(
            AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue, 7
        )
    UNSPECIFIED = typing___cast(
        AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue, 0
    )
    UNKNOWN = typing___cast(AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue, 1)
    SEARCH = typing___cast(AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue, 2)
    DISPLAY = typing___cast(AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue, 3)
    SHOPPING = typing___cast(AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue, 4)
    HOTEL = typing___cast(AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue, 5)
    VIDEO = typing___cast(AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue, 6)
    MULTI_CHANNEL = typing___cast(
        AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue, 7
    )
    type___AdvertisingChannelType = AdvertisingChannelType
    def __init__(self,) -> None: ...

type___AdvertisingChannelTypeEnum = AdvertisingChannelTypeEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional, Text as typing___Text

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.common.asset_policy_pb2 import (
    AdAssetPolicySummary as google___ads___googleads___v6___common___asset_policy_pb2___AdAssetPolicySummary,
)
from google.ads.google_ads.v6.proto.enums.asset_performance_label_pb2 import (
    AssetPerformanceLabelEnum as google___ads___googleads___v6___enums___asset_performance_label_pb2___AssetPerformanceLabelEnum,
)
from google.ads.google_ads.v6.proto.enums.served_asset_field_type_pb2 import (
    ServedAssetFieldTypeEnum as google___ads___googleads___v6___enums___served_asset_field_type_pb2___ServedAssetFieldTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AdTextAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    text: typing___Text = ...
    pinned_field: google___ads___googleads___v6___enums___served_asset_field_type_pb2___ServedAssetFieldTypeEnum.ServedAssetFieldTypeValue = ...
    asset_performance_label: google___ads___googleads___v6___enums___asset_performance_label_pb2___AssetPerformanceLabelEnum.AssetPerformanceLabelValue = ...
    @property
    def policy_summary_info(
        self,
    ) -> google___ads___googleads___v6___common___asset_policy_pb2___AdAssetPolicySummary: ...
    def __init__(
        self,
        *,
        text: typing___Optional[typing___Text] = None,
        pinned_field: typing___Optional[
            google___ads___googleads___v6___enums___served_asset_field_type_pb2___ServedAssetFieldTypeEnum.ServedAssetFieldTypeValue
        ] = None,
        asset_performance_label: typing___Optional[
            google___ads___googleads___v6___enums___asset_performance_label_pb2___AssetPerformanceLabelEnum.AssetPerformanceLabelValue
        ] = None,
        policy_summary_info: typing___Optional[
            google___ads___googleads___v6___common___asset_policy_pb2___AdAssetPolicySummary
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_text",
            b"_text",
            "policy_summary_info",
            b"policy_summary_info",
            "text",
            b"text",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_text",
            b"_text",
            "asset_performance_label",
            b"asset_performance_label",
            "pinned_field",
            b"pinned_field",
            "policy_summary_info",
            b"policy_summary_info",
            "text",
            b"text",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_text", b"_text"]
    ) -> typing_extensions___Literal["text"]: ...

type___AdTextAsset = AdTextAsset

class AdImageAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    asset: typing___Text = ...
    def __init__(self, *, asset: typing___Optional[typing___Text] = None,) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal["_asset", b"_asset", "asset", b"asset"],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal["_asset", b"_asset", "asset", b"asset"],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_asset", b"_asset"]
    ) -> typing_extensions___Literal["asset"]: ...

type___AdImageAsset = AdImageAsset

class AdVideoAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    asset: typing___Text = ...
    def __init__(self, *, asset: typing___Optional[typing___Text] = None,) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal["_asset", b"_asset", "asset", b"asset"],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal["_asset", b"_asset", "asset", b"asset"],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_asset", b"_asset"]
    ) -> typing_extensions___Literal["asset"]: ...

type___AdVideoAsset = AdVideoAsset

class AdMediaBundleAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    asset: typing___Text = ...
    def __init__(self, *, asset: typing___Optional[typing___Text] = None,) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal["_asset", b"_asset", "asset", b"asset"],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal["_asset", b"_asset", "asset", b"asset"],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_asset", b"_asset"]
    ) -> typing_extensions___Literal["asset"]: ...

type___AdMediaBundleAsset = AdMediaBundleAsset



from typing import Any

class AdGroupBidModifierServiceStub:
    GetAdGroupBidModifier: Any = ...
    MutateAdGroupBidModifiers: Any = ...
    def __init__(self, channel: Any) -> None: ...

class AdGroupBidModifierServiceServicer:
    def GetAdGroupBidModifier(self, request: Any, context: Any) -> None: ...
    def MutateAdGroupBidModifiers(self, request: Any, context: Any) -> None: ...

def add_AdGroupBidModifierServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



from typing import Any, List, NamedTuple, Optional, Tuple

import grpc  # type: ignore


class _ClientCallDetails(
    NamedTuple(
        "_ClientCallDetails",
        [
            ("method", str),
            ("timeout", float),
            ("metadata", List[Tuple[str, Any]]),
            ("credentials", Optional[grpc.CallCredentials]),
        ],
    ),
    grpc.ClientCallDetails,
):
    pass


class Interceptor:
    @classmethod
    def get_request_id_from_metadata(
        cls, trailing_metadata: Tuple[Tuple[str, Any]]
    ) -> Optional[str]:
        ...

    @classmethod
    def parse_metadata_to_json(cls, metadata: List[Tuple[str, Any]]) -> str:
        ...

    @classmethod
    def format_json_object(cls, obj: Any) -> str:
        ...

    @classmethod
    def get_trailing_metadata_from_interceptor_exception(
        cls, exception
    ) -> Tuple[Tuple[str, Any]]:
        ...

    @classmethod
    def get_client_call_details_instance(
        cls,
        method: str,
        timeout: float,
        metadata: List[Tuple[str, Any]],
        credentials: Optional[grpc.CallCredentials] = ...,
    ) -> None:
        ...

    def __init__(self, api_version: str) -> None:
        ...



from typing import Callable, TypeVar

import grpc  # type: ignore

from .interceptor import Interceptor

_Request = TypeVar("_Request")
_Response = TypeVar("_Response")

class ExceptionInterceptor(
    Interceptor, grpc.UnaryUnaryClientInterceptor, grpc.UnaryStreamClientInterceptor
):
    def __init__(self, api_version: str) -> None: ...
    def intercept_unary_unary(
        self,
        continuation: Callable[[grpc.ClientCallDetails, _Request], _Response],
        client_call_details: grpc.ClientCallDetails,
        request: _Request,
    ) -> _Response: ...



from typing import Any

class KeywordPlanAdGroupKeywordServiceStub:
    GetKeywordPlanAdGroupKeyword: Any = ...
    MutateKeywordPlanAdGroupKeywords: Any = ...
    def __init__(self, channel: Any) -> None: ...

class KeywordPlanAdGroupKeywordServiceServicer:
    def GetKeywordPlanAdGroupKeyword(self, request: Any, context: Any) -> None: ...
    def MutateKeywordPlanAdGroupKeywords(self, request: Any, context: Any) -> None: ...

def add_KeywordPlanAdGroupKeywordServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class FeedItemValidationErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    FeedItemValidationErrorValue = typing___NewType(
        "FeedItemValidationErrorValue", builtin___int
    )
    type___FeedItemValidationErrorValue = FeedItemValidationErrorValue
    FeedItemValidationError: _FeedItemValidationError
    class _FeedItemValidationError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 0
        )
        UNKNOWN = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 1
        )
        STRING_TOO_SHORT = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 2
        )
        STRING_TOO_LONG = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 3
        )
        VALUE_NOT_SPECIFIED = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 4
        )
        INVALID_DOMESTIC_PHONE_NUMBER_FORMAT = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 5
        )
        INVALID_PHONE_NUMBER = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 6
        )
        PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 7
        )
        PREMIUM_RATE_NUMBER_NOT_ALLOWED = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 8
        )
        DISALLOWED_NUMBER_TYPE = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 9
        )
        VALUE_OUT_OF_RANGE = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 10
        )
        CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 11
        )
        CUSTOMER_NOT_IN_ALLOWLIST_FOR_CALLTRACKING = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 99
        )
        INVALID_COUNTRY_CODE = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 13
        )
        INVALID_APP_ID = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 14
        )
        MISSING_ATTRIBUTES_FOR_FIELDS = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 15
        )
        INVALID_TYPE_ID = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 16
        )
        INVALID_EMAIL_ADDRESS = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 17
        )
        INVALID_HTTPS_URL = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 18
        )
        MISSING_DELIVERY_ADDRESS = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 19
        )
        START_DATE_AFTER_END_DATE = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 20
        )
        MISSING_FEED_ITEM_START_TIME = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 21
        )
        MISSING_FEED_ITEM_END_TIME = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 22
        )
        MISSING_FEED_ITEM_ID = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 23
        )
        VANITY_PHONE_NUMBER_NOT_ALLOWED = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 24
        )
        INVALID_REVIEW_EXTENSION_SNIPPET = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 25
        )
        INVALID_NUMBER_FORMAT = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 26
        )
        INVALID_DATE_FORMAT = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 27
        )
        INVALID_PRICE_FORMAT = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 28
        )
        UNKNOWN_PLACEHOLDER_FIELD = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 29
        )
        MISSING_ENHANCED_SITELINK_DESCRIPTION_LINE = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 30
        )
        REVIEW_EXTENSION_SOURCE_INELIGIBLE = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 31
        )
        HYPHENS_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 32
        )
        DOUBLE_QUOTES_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 33
        )
        QUOTES_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 34
        )
        INVALID_FORM_ENCODED_PARAMS = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 35
        )
        INVALID_URL_PARAMETER_NAME = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 36
        )
        NO_GEOCODING_RESULT = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 37
        )
        SOURCE_NAME_IN_REVIEW_EXTENSION_TEXT = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 38
        )
        CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 39
        )
        INVALID_PLACEHOLDER_FIELD_ID = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 40
        )
        INVALID_URL_TAG = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 41
        )
        LIST_TOO_LONG = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 42
        )
        INVALID_ATTRIBUTES_COMBINATION = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 43
        )
        DUPLICATE_VALUES = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 44
        )
        INVALID_CALL_CONVERSION_ACTION_ID = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 45
        )
        CANNOT_SET_WITHOUT_FINAL_URLS = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 46
        )
        APP_ID_DOESNT_EXIST_IN_APP_STORE = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 47
        )
        INVALID_FINAL_URL = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 48
        )
        INVALID_TRACKING_URL = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 49
        )
        INVALID_FINAL_URL_FOR_APP_DOWNLOAD_URL = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 50
        )
        LIST_TOO_SHORT = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 51
        )
        INVALID_USER_ACTION = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 52
        )
        INVALID_TYPE_NAME = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 53
        )
        INVALID_EVENT_CHANGE_STATUS = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 54
        )
        INVALID_SNIPPETS_HEADER = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 55
        )
        INVALID_ANDROID_APP_LINK = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 56
        )
        NUMBER_TYPE_WITH_CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 57
        )
        RESERVED_KEYWORD_OTHER = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 58
        )
        DUPLICATE_OPTION_LABELS = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 59
        )
        DUPLICATE_OPTION_PREFILLS = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 60
        )
        UNEQUAL_LIST_LENGTHS = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 61
        )
        INCONSISTENT_CURRENCY_CODES = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 62
        )
        PRICE_EXTENSION_HAS_DUPLICATED_HEADERS = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 63
        )
        ITEM_HAS_DUPLICATED_HEADER_AND_DESCRIPTION = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 64
        )
        PRICE_EXTENSION_HAS_TOO_FEW_ITEMS = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 65
        )
        UNSUPPORTED_VALUE = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 66
        )
        INVALID_FINAL_MOBILE_URL = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 67
        )
        INVALID_KEYWORDLESS_AD_RULE_LABEL = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 68
        )
        VALUE_TRACK_PARAMETER_NOT_SUPPORTED = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 69
        )
        UNSUPPORTED_VALUE_IN_SELECTED_LANGUAGE = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 70
        )
        INVALID_IOS_APP_LINK = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 71
        )
        MISSING_IOS_APP_LINK_OR_IOS_APP_STORE_ID = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 72
        )
        PROMOTION_INVALID_TIME = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 73
        )
        PROMOTION_CANNOT_SET_PERCENT_OFF_AND_MONEY_AMOUNT_OFF = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 74
        )
        PROMOTION_CANNOT_SET_PROMOTION_CODE_AND_ORDERS_OVER_AMOUNT = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 75
        )
        TOO_MANY_DECIMAL_PLACES_SPECIFIED = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 76
        )
        AD_CUSTOMIZERS_NOT_ALLOWED = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 77
        )
        INVALID_LANGUAGE_CODE = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 78
        )
        UNSUPPORTED_LANGUAGE = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 79
        )
        IF_FUNCTION_NOT_ALLOWED = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 80
        )
        INVALID_FINAL_URL_SUFFIX = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 81
        )
        INVALID_TAG_IN_FINAL_URL_SUFFIX = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 82
        )
        INVALID_FINAL_URL_SUFFIX_FORMAT = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 83
        )
        CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 84
        )
        ONLY_ONE_DELIVERY_OPTION_IS_ALLOWED = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 85
        )
        NO_DELIVERY_OPTION_IS_SET = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 86
        )
        INVALID_CONVERSION_REPORTING_STATE = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 87
        )
        IMAGE_SIZE_WRONG = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 88
        )
        EMAIL_DELIVERY_NOT_AVAILABLE_IN_COUNTRY = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 89
        )
        AUTO_REPLY_NOT_AVAILABLE_IN_COUNTRY = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 90
        )
        INVALID_LATITUDE_VALUE = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 91
        )
        INVALID_LONGITUDE_VALUE = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 92
        )
        TOO_MANY_LABELS = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 93
        )
        INVALID_IMAGE_URL = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 94
        )
        MISSING_LATITUDE_VALUE = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 95
        )
        MISSING_LONGITUDE_VALUE = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 96
        )
        ADDRESS_NOT_FOUND = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 97
        )
        ADDRESS_NOT_TARGETABLE = typing___cast(
            FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 98
        )
    UNSPECIFIED = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 0
    )
    UNKNOWN = typing___cast(FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 1)
    STRING_TOO_SHORT = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 2
    )
    STRING_TOO_LONG = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 3
    )
    VALUE_NOT_SPECIFIED = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 4
    )
    INVALID_DOMESTIC_PHONE_NUMBER_FORMAT = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 5
    )
    INVALID_PHONE_NUMBER = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 6
    )
    PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 7
    )
    PREMIUM_RATE_NUMBER_NOT_ALLOWED = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 8
    )
    DISALLOWED_NUMBER_TYPE = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 9
    )
    VALUE_OUT_OF_RANGE = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 10
    )
    CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 11
    )
    CUSTOMER_NOT_IN_ALLOWLIST_FOR_CALLTRACKING = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 99
    )
    INVALID_COUNTRY_CODE = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 13
    )
    INVALID_APP_ID = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 14
    )
    MISSING_ATTRIBUTES_FOR_FIELDS = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 15
    )
    INVALID_TYPE_ID = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 16
    )
    INVALID_EMAIL_ADDRESS = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 17
    )
    INVALID_HTTPS_URL = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 18
    )
    MISSING_DELIVERY_ADDRESS = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 19
    )
    START_DATE_AFTER_END_DATE = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 20
    )
    MISSING_FEED_ITEM_START_TIME = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 21
    )
    MISSING_FEED_ITEM_END_TIME = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 22
    )
    MISSING_FEED_ITEM_ID = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 23
    )
    VANITY_PHONE_NUMBER_NOT_ALLOWED = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 24
    )
    INVALID_REVIEW_EXTENSION_SNIPPET = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 25
    )
    INVALID_NUMBER_FORMAT = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 26
    )
    INVALID_DATE_FORMAT = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 27
    )
    INVALID_PRICE_FORMAT = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 28
    )
    UNKNOWN_PLACEHOLDER_FIELD = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 29
    )
    MISSING_ENHANCED_SITELINK_DESCRIPTION_LINE = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 30
    )
    REVIEW_EXTENSION_SOURCE_INELIGIBLE = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 31
    )
    HYPHENS_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 32
    )
    DOUBLE_QUOTES_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 33
    )
    QUOTES_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 34
    )
    INVALID_FORM_ENCODED_PARAMS = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 35
    )
    INVALID_URL_PARAMETER_NAME = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 36
    )
    NO_GEOCODING_RESULT = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 37
    )
    SOURCE_NAME_IN_REVIEW_EXTENSION_TEXT = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 38
    )
    CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 39
    )
    INVALID_PLACEHOLDER_FIELD_ID = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 40
    )
    INVALID_URL_TAG = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 41
    )
    LIST_TOO_LONG = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 42
    )
    INVALID_ATTRIBUTES_COMBINATION = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 43
    )
    DUPLICATE_VALUES = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 44
    )
    INVALID_CALL_CONVERSION_ACTION_ID = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 45
    )
    CANNOT_SET_WITHOUT_FINAL_URLS = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 46
    )
    APP_ID_DOESNT_EXIST_IN_APP_STORE = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 47
    )
    INVALID_FINAL_URL = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 48
    )
    INVALID_TRACKING_URL = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 49
    )
    INVALID_FINAL_URL_FOR_APP_DOWNLOAD_URL = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 50
    )
    LIST_TOO_SHORT = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 51
    )
    INVALID_USER_ACTION = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 52
    )
    INVALID_TYPE_NAME = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 53
    )
    INVALID_EVENT_CHANGE_STATUS = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 54
    )
    INVALID_SNIPPETS_HEADER = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 55
    )
    INVALID_ANDROID_APP_LINK = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 56
    )
    NUMBER_TYPE_WITH_CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 57
    )
    RESERVED_KEYWORD_OTHER = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 58
    )
    DUPLICATE_OPTION_LABELS = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 59
    )
    DUPLICATE_OPTION_PREFILLS = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 60
    )
    UNEQUAL_LIST_LENGTHS = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 61
    )
    INCONSISTENT_CURRENCY_CODES = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 62
    )
    PRICE_EXTENSION_HAS_DUPLICATED_HEADERS = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 63
    )
    ITEM_HAS_DUPLICATED_HEADER_AND_DESCRIPTION = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 64
    )
    PRICE_EXTENSION_HAS_TOO_FEW_ITEMS = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 65
    )
    UNSUPPORTED_VALUE = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 66
    )
    INVALID_FINAL_MOBILE_URL = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 67
    )
    INVALID_KEYWORDLESS_AD_RULE_LABEL = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 68
    )
    VALUE_TRACK_PARAMETER_NOT_SUPPORTED = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 69
    )
    UNSUPPORTED_VALUE_IN_SELECTED_LANGUAGE = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 70
    )
    INVALID_IOS_APP_LINK = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 71
    )
    MISSING_IOS_APP_LINK_OR_IOS_APP_STORE_ID = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 72
    )
    PROMOTION_INVALID_TIME = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 73
    )
    PROMOTION_CANNOT_SET_PERCENT_OFF_AND_MONEY_AMOUNT_OFF = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 74
    )
    PROMOTION_CANNOT_SET_PROMOTION_CODE_AND_ORDERS_OVER_AMOUNT = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 75
    )
    TOO_MANY_DECIMAL_PLACES_SPECIFIED = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 76
    )
    AD_CUSTOMIZERS_NOT_ALLOWED = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 77
    )
    INVALID_LANGUAGE_CODE = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 78
    )
    UNSUPPORTED_LANGUAGE = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 79
    )
    IF_FUNCTION_NOT_ALLOWED = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 80
    )
    INVALID_FINAL_URL_SUFFIX = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 81
    )
    INVALID_TAG_IN_FINAL_URL_SUFFIX = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 82
    )
    INVALID_FINAL_URL_SUFFIX_FORMAT = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 83
    )
    CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 84
    )
    ONLY_ONE_DELIVERY_OPTION_IS_ALLOWED = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 85
    )
    NO_DELIVERY_OPTION_IS_SET = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 86
    )
    INVALID_CONVERSION_REPORTING_STATE = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 87
    )
    IMAGE_SIZE_WRONG = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 88
    )
    EMAIL_DELIVERY_NOT_AVAILABLE_IN_COUNTRY = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 89
    )
    AUTO_REPLY_NOT_AVAILABLE_IN_COUNTRY = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 90
    )
    INVALID_LATITUDE_VALUE = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 91
    )
    INVALID_LONGITUDE_VALUE = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 92
    )
    TOO_MANY_LABELS = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 93
    )
    INVALID_IMAGE_URL = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 94
    )
    MISSING_LATITUDE_VALUE = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 95
    )
    MISSING_LONGITUDE_VALUE = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 96
    )
    ADDRESS_NOT_FOUND = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 97
    )
    ADDRESS_NOT_TARGETABLE = typing___cast(
        FeedItemValidationErrorEnum.FeedItemValidationErrorValue, 98
    )
    type___FeedItemValidationError = FeedItemValidationError
    def __init__(self,) -> None: ...

type___FeedItemValidationErrorEnum = FeedItemValidationErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Iterable as typing___Iterable, Optional as typing___Optional

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
    RepeatedScalarFieldContainer as google___protobuf___internal___containers___RepeatedScalarFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v3.proto.enums.advertising_channel_sub_type_pb2 import (
    AdvertisingChannelSubTypeEnum as google___ads___googleads___v3___enums___advertising_channel_sub_type_pb2___AdvertisingChannelSubTypeEnum,
)
from google.ads.google_ads.v3.proto.enums.advertising_channel_type_pb2 import (
    AdvertisingChannelTypeEnum as google___ads___googleads___v3___enums___advertising_channel_type_pb2___AdvertisingChannelTypeEnum,
)
from google.ads.google_ads.v3.proto.enums.criterion_category_channel_availability_mode_pb2 import (
    CriterionCategoryChannelAvailabilityModeEnum as google___ads___googleads___v3___enums___criterion_category_channel_availability_mode_pb2___CriterionCategoryChannelAvailabilityModeEnum,
)
from google.ads.google_ads.v3.proto.enums.criterion_category_locale_availability_mode_pb2 import (
    CriterionCategoryLocaleAvailabilityModeEnum as google___ads___googleads___v3___enums___criterion_category_locale_availability_mode_pb2___CriterionCategoryLocaleAvailabilityModeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CriterionCategoryAvailability(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def channel(self) -> type___CriterionCategoryChannelAvailability: ...
    @property
    def locale(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___CriterionCategoryLocaleAvailability
    ]: ...
    def __init__(
        self,
        *,
        channel: typing___Optional[type___CriterionCategoryChannelAvailability] = None,
        locale: typing___Optional[
            typing___Iterable[type___CriterionCategoryLocaleAvailability]
        ] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["channel", b"channel"]
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "channel", b"channel", "locale", b"locale"
        ],
    ) -> None: ...

type___CriterionCategoryAvailability = CriterionCategoryAvailability

class CriterionCategoryChannelAvailability(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    availability_mode: google___ads___googleads___v3___enums___criterion_category_channel_availability_mode_pb2___CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityModeValue = ...
    advertising_channel_type: google___ads___googleads___v3___enums___advertising_channel_type_pb2___AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue = ...
    advertising_channel_sub_type: google___protobuf___internal___containers___RepeatedScalarFieldContainer[
        google___ads___googleads___v3___enums___advertising_channel_sub_type_pb2___AdvertisingChannelSubTypeEnum.AdvertisingChannelSubTypeValue
    ] = ...
    @property
    def include_default_channel_sub_type(
        self,
    ) -> google___protobuf___wrappers_pb2___BoolValue: ...
    def __init__(
        self,
        *,
        availability_mode: typing___Optional[
            google___ads___googleads___v3___enums___criterion_category_channel_availability_mode_pb2___CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityModeValue
        ] = None,
        advertising_channel_type: typing___Optional[
            google___ads___googleads___v3___enums___advertising_channel_type_pb2___AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue
        ] = None,
        advertising_channel_sub_type: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v3___enums___advertising_channel_sub_type_pb2___AdvertisingChannelSubTypeEnum.AdvertisingChannelSubTypeValue
            ]
        ] = None,
        include_default_channel_sub_type: typing___Optional[
            google___protobuf___wrappers_pb2___BoolValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "include_default_channel_sub_type", b"include_default_channel_sub_type"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "advertising_channel_sub_type",
            b"advertising_channel_sub_type",
            "advertising_channel_type",
            b"advertising_channel_type",
            "availability_mode",
            b"availability_mode",
            "include_default_channel_sub_type",
            b"include_default_channel_sub_type",
        ],
    ) -> None: ...

type___CriterionCategoryChannelAvailability = CriterionCategoryChannelAvailability

class CriterionCategoryLocaleAvailability(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    availability_mode: google___ads___googleads___v3___enums___criterion_category_locale_availability_mode_pb2___CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityModeValue = ...
    @property
    def country_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def language_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        availability_mode: typing___Optional[
            google___ads___googleads___v3___enums___criterion_category_locale_availability_mode_pb2___CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityModeValue
        ] = None,
        country_code: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        language_code: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "country_code", b"country_code", "language_code", b"language_code"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "availability_mode",
            b"availability_mode",
            "country_code",
            b"country_code",
            "language_code",
            b"language_code",
        ],
    ) -> None: ...

type___CriterionCategoryLocaleAvailability = CriterionCategoryLocaleAvailability



from typing import Any

class CampaignCriterionServiceStub:
    GetCampaignCriterion: Any = ...
    MutateCampaignCriteria: Any = ...
    def __init__(self, channel: Any) -> None: ...

class CampaignCriterionServiceServicer:
    def GetCampaignCriterion(self, request: Any, context: Any) -> None: ...
    def MutateCampaignCriteria(self, request: Any, context: Any) -> None: ...

def add_CampaignCriterionServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class BiddingStrategyErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    BiddingStrategyErrorValue = typing___NewType(
        "BiddingStrategyErrorValue", builtin___int
    )
    type___BiddingStrategyErrorValue = BiddingStrategyErrorValue
    BiddingStrategyError: _BiddingStrategyError
    class _BiddingStrategyError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            BiddingStrategyErrorEnum.BiddingStrategyErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            BiddingStrategyErrorEnum.BiddingStrategyErrorValue, 0
        )
        UNKNOWN = typing___cast(BiddingStrategyErrorEnum.BiddingStrategyErrorValue, 1)
        DUPLICATE_NAME = typing___cast(
            BiddingStrategyErrorEnum.BiddingStrategyErrorValue, 2
        )
        CANNOT_CHANGE_BIDDING_STRATEGY_TYPE = typing___cast(
            BiddingStrategyErrorEnum.BiddingStrategyErrorValue, 3
        )
        CANNOT_REMOVE_ASSOCIATED_STRATEGY = typing___cast(
            BiddingStrategyErrorEnum.BiddingStrategyErrorValue, 4
        )
        BIDDING_STRATEGY_NOT_SUPPORTED = typing___cast(
            BiddingStrategyErrorEnum.BiddingStrategyErrorValue, 5
        )
        INCOMPATIBLE_BIDDING_STRATEGY_AND_BIDDING_STRATEGY_GOAL_TYPE = typing___cast(
            BiddingStrategyErrorEnum.BiddingStrategyErrorValue, 6
        )
    UNSPECIFIED = typing___cast(BiddingStrategyErrorEnum.BiddingStrategyErrorValue, 0)
    UNKNOWN = typing___cast(BiddingStrategyErrorEnum.BiddingStrategyErrorValue, 1)
    DUPLICATE_NAME = typing___cast(
        BiddingStrategyErrorEnum.BiddingStrategyErrorValue, 2
    )
    CANNOT_CHANGE_BIDDING_STRATEGY_TYPE = typing___cast(
        BiddingStrategyErrorEnum.BiddingStrategyErrorValue, 3
    )
    CANNOT_REMOVE_ASSOCIATED_STRATEGY = typing___cast(
        BiddingStrategyErrorEnum.BiddingStrategyErrorValue, 4
    )
    BIDDING_STRATEGY_NOT_SUPPORTED = typing___cast(
        BiddingStrategyErrorEnum.BiddingStrategyErrorValue, 5
    )
    INCOMPATIBLE_BIDDING_STRATEGY_AND_BIDDING_STRATEGY_GOAL_TYPE = typing___cast(
        BiddingStrategyErrorEnum.BiddingStrategyErrorValue, 6
    )
    type___BiddingStrategyError = BiddingStrategyError
    def __init__(self,) -> None: ...

type___BiddingStrategyErrorEnum = BiddingStrategyErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class HotelDateSelectionTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    HotelDateSelectionTypeValue = typing___NewType(
        "HotelDateSelectionTypeValue", builtin___int
    )
    type___HotelDateSelectionTypeValue = HotelDateSelectionTypeValue
    HotelDateSelectionType: _HotelDateSelectionType
    class _HotelDateSelectionType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            HotelDateSelectionTypeEnum.HotelDateSelectionTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            HotelDateSelectionTypeEnum.HotelDateSelectionTypeValue, 0
        )
        UNKNOWN = typing___cast(
            HotelDateSelectionTypeEnum.HotelDateSelectionTypeValue, 1
        )
        DEFAULT_SELECTION = typing___cast(
            HotelDateSelectionTypeEnum.HotelDateSelectionTypeValue, 50
        )
        USER_SELECTED = typing___cast(
            HotelDateSelectionTypeEnum.HotelDateSelectionTypeValue, 51
        )
    UNSPECIFIED = typing___cast(
        HotelDateSelectionTypeEnum.HotelDateSelectionTypeValue, 0
    )
    UNKNOWN = typing___cast(HotelDateSelectionTypeEnum.HotelDateSelectionTypeValue, 1)
    DEFAULT_SELECTION = typing___cast(
        HotelDateSelectionTypeEnum.HotelDateSelectionTypeValue, 50
    )
    USER_SELECTED = typing___cast(
        HotelDateSelectionTypeEnum.HotelDateSelectionTypeValue, 51
    )
    type___HotelDateSelectionType = HotelDateSelectionType
    def __init__(self,) -> None: ...

type___HotelDateSelectionTypeEnum = HotelDateSelectionTypeEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v5.proto.common.policy_pb2 import (
    PolicyTopicEntry as google___ads___googleads___v5___common___policy_pb2___PolicyTopicEntry,
)
from google.ads.google_ads.v5.proto.enums.ad_group_ad_status_pb2 import (
    AdGroupAdStatusEnum as google___ads___googleads___v5___enums___ad_group_ad_status_pb2___AdGroupAdStatusEnum,
)
from google.ads.google_ads.v5.proto.enums.ad_strength_pb2 import (
    AdStrengthEnum as google___ads___googleads___v5___enums___ad_strength_pb2___AdStrengthEnum,
)
from google.ads.google_ads.v5.proto.enums.policy_approval_status_pb2 import (
    PolicyApprovalStatusEnum as google___ads___googleads___v5___enums___policy_approval_status_pb2___PolicyApprovalStatusEnum,
)
from google.ads.google_ads.v5.proto.enums.policy_review_status_pb2 import (
    PolicyReviewStatusEnum as google___ads___googleads___v5___enums___policy_review_status_pb2___PolicyReviewStatusEnum,
)
from google.ads.google_ads.v5.proto.resources.ad_pb2 import (
    Ad as google___ads___googleads___v5___resources___ad_pb2___Ad,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AdGroupAd(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    status: google___ads___googleads___v5___enums___ad_group_ad_status_pb2___AdGroupAdStatusEnum.AdGroupAdStatusValue = ...
    ad_group: typing___Text = ...
    ad_strength: google___ads___googleads___v5___enums___ad_strength_pb2___AdStrengthEnum.AdStrengthValue = ...
    @property
    def ad(self) -> google___ads___googleads___v5___resources___ad_pb2___Ad: ...
    @property
    def policy_summary(self) -> type___AdGroupAdPolicySummary: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        status: typing___Optional[
            google___ads___googleads___v5___enums___ad_group_ad_status_pb2___AdGroupAdStatusEnum.AdGroupAdStatusValue
        ] = None,
        ad_group: typing___Optional[typing___Text] = None,
        ad: typing___Optional[
            google___ads___googleads___v5___resources___ad_pb2___Ad
        ] = None,
        policy_summary: typing___Optional[type___AdGroupAdPolicySummary] = None,
        ad_strength: typing___Optional[
            google___ads___googleads___v5___enums___ad_strength_pb2___AdStrengthEnum.AdStrengthValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_ad_group",
            b"_ad_group",
            "ad",
            b"ad",
            "ad_group",
            b"ad_group",
            "policy_summary",
            b"policy_summary",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_ad_group",
            b"_ad_group",
            "ad",
            b"ad",
            "ad_group",
            b"ad_group",
            "ad_strength",
            b"ad_strength",
            "policy_summary",
            b"policy_summary",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_ad_group", b"_ad_group"]
    ) -> typing_extensions___Literal["ad_group"]: ...

type___AdGroupAd = AdGroupAd

class AdGroupAdPolicySummary(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    review_status: google___ads___googleads___v5___enums___policy_review_status_pb2___PolicyReviewStatusEnum.PolicyReviewStatusValue = ...
    approval_status: google___ads___googleads___v5___enums___policy_approval_status_pb2___PolicyApprovalStatusEnum.PolicyApprovalStatusValue = ...
    @property
    def policy_topic_entries(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v5___common___policy_pb2___PolicyTopicEntry
    ]: ...
    def __init__(
        self,
        *,
        policy_topic_entries: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v5___common___policy_pb2___PolicyTopicEntry
            ]
        ] = None,
        review_status: typing___Optional[
            google___ads___googleads___v5___enums___policy_review_status_pb2___PolicyReviewStatusEnum.PolicyReviewStatusValue
        ] = None,
        approval_status: typing___Optional[
            google___ads___googleads___v5___enums___policy_approval_status_pb2___PolicyApprovalStatusEnum.PolicyApprovalStatusValue
        ] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "approval_status",
            b"approval_status",
            "policy_topic_entries",
            b"policy_topic_entries",
            "review_status",
            b"review_status",
        ],
    ) -> None: ...

type___AdGroupAdPolicySummary = AdGroupAdPolicySummary



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class Money(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    currency_code: typing___Text = ...
    amount_micros: builtin___int = ...
    def __init__(
        self,
        *,
        currency_code: typing___Optional[typing___Text] = None,
        amount_micros: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_amount_micros",
            b"_amount_micros",
            "_currency_code",
            b"_currency_code",
            "amount_micros",
            b"amount_micros",
            "currency_code",
            b"currency_code",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_amount_micros",
            b"_amount_micros",
            "_currency_code",
            b"_currency_code",
            "amount_micros",
            b"amount_micros",
            "currency_code",
            b"currency_code",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_amount_micros", b"_amount_micros"],
    ) -> typing_extensions___Literal["amount_micros"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_currency_code", b"_currency_code"],
    ) -> typing_extensions___Literal["currency_code"]: ...

type___Money = Money



from typing import Any

class ProductGroupViewServiceStub:
    GetProductGroupView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class ProductGroupViewServiceServicer:
    def GetProductGroupView(self, request: Any, context: Any) -> None: ...

def add_ProductGroupViewServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



from typing import Any, Optional

class ConversionActionServiceStub:
    GetConversionAction: Any = ...
    MutateConversionActions: Any = ...
    def __init__(self, channel: Any) -> None: ...

class ConversionActionServiceServicer:
    def GetConversionAction(self, request: Any, context: Any) -> None: ...
    def MutateConversionActions(self, request: Any, context: Any) -> None: ...

def add_ConversionActionServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...

class ConversionActionService:
    @staticmethod
    def GetConversionAction(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...
    @staticmethod
    def MutateConversionActions(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CampaignCriterionStatusEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    CampaignCriterionStatusValue = typing___NewType(
        "CampaignCriterionStatusValue", builtin___int
    )
    type___CampaignCriterionStatusValue = CampaignCriterionStatusValue
    CampaignCriterionStatus: _CampaignCriterionStatus
    class _CampaignCriterionStatus(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            CampaignCriterionStatusEnum.CampaignCriterionStatusValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            CampaignCriterionStatusEnum.CampaignCriterionStatusValue, 0
        )
        UNKNOWN = typing___cast(
            CampaignCriterionStatusEnum.CampaignCriterionStatusValue, 1
        )
        ENABLED = typing___cast(
            CampaignCriterionStatusEnum.CampaignCriterionStatusValue, 2
        )
        PAUSED = typing___cast(
            CampaignCriterionStatusEnum.CampaignCriterionStatusValue, 3
        )
        REMOVED = typing___cast(
            CampaignCriterionStatusEnum.CampaignCriterionStatusValue, 4
        )
    UNSPECIFIED = typing___cast(
        CampaignCriterionStatusEnum.CampaignCriterionStatusValue, 0
    )
    UNKNOWN = typing___cast(CampaignCriterionStatusEnum.CampaignCriterionStatusValue, 1)
    ENABLED = typing___cast(CampaignCriterionStatusEnum.CampaignCriterionStatusValue, 2)
    PAUSED = typing___cast(CampaignCriterionStatusEnum.CampaignCriterionStatusValue, 3)
    REMOVED = typing___cast(CampaignCriterionStatusEnum.CampaignCriterionStatusValue, 4)
    type___CampaignCriterionStatus = CampaignCriterionStatus
    def __init__(self,) -> None: ...

type___CampaignCriterionStatusEnum = CampaignCriterionStatusEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v3.proto.enums.extension_setting_device_pb2 import (
    ExtensionSettingDeviceEnum as google___ads___googleads___v3___enums___extension_setting_device_pb2___ExtensionSettingDeviceEnum,
)
from google.ads.google_ads.v3.proto.enums.extension_type_pb2 import (
    ExtensionTypeEnum as google___ads___googleads___v3___enums___extension_type_pb2___ExtensionTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CampaignExtensionSetting(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    extension_type: google___ads___googleads___v3___enums___extension_type_pb2___ExtensionTypeEnum.ExtensionTypeValue = ...
    device: google___ads___googleads___v3___enums___extension_setting_device_pb2___ExtensionSettingDeviceEnum.ExtensionSettingDeviceValue = ...
    @property
    def campaign(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def extension_feed_items(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___protobuf___wrappers_pb2___StringValue
    ]: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        extension_type: typing___Optional[
            google___ads___googleads___v3___enums___extension_type_pb2___ExtensionTypeEnum.ExtensionTypeValue
        ] = None,
        campaign: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        extension_feed_items: typing___Optional[
            typing___Iterable[google___protobuf___wrappers_pb2___StringValue]
        ] = None,
        device: typing___Optional[
            google___ads___googleads___v3___enums___extension_setting_device_pb2___ExtensionSettingDeviceEnum.ExtensionSettingDeviceValue
        ] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["campaign", b"campaign"]
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "campaign",
            b"campaign",
            "device",
            b"device",
            "extension_feed_items",
            b"extension_feed_items",
            "extension_type",
            b"extension_type",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...

type___CampaignExtensionSetting = CampaignExtensionSetting
